.. default-intersphinx:: rb2.5


===================================
Review Board 2.5.13.1 Release Notes
===================================

**Release date**: June 20, 2017


.. note::

   This is a patch release fixing a last-minute breaking bug in 2.5.13.
   Please see the :doc:`2.5.13 release notes <2.5.13>` for important security
   updates and other fixes.


Bug Fixes
=========

* Fixed a breaking bug in the new :command:`rb-site --version` code from
  2.5.13.


Contributors
============

* Christian Hammond
